# rapidata.api-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `rapidata.api_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Generator version: 7.9.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* pydantic

## Getting Started

In your own code, to use this library to connect and interact with rapidata.api-client,
you can run the following:

```python

import rapidata.api_client
from rapidata.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = rapidata.api_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: bearer
configuration.api_key['bearer'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['bearer'] = 'Bearer'


# Enter a context with an instance of the API client
with rapidata.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = rapidata.api_client.CocoApi(api_client)
    submit_coco_model = rapidata.api_client.SubmitCocoModel() # SubmitCocoModel | The model containing the information needed to create the validation set. (optional)

    try:
        # Creates a new validation set based on a previously uploaded CoCo set.
        api_response = api_instance.coco_submit_post(submit_coco_model=submit_coco_model)
        print("The response of CocoApi->coco_submit_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CocoApi->coco_submit_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CocoApi* | [**coco_submit_post**](rapidata/api_client/docs/CocoApi.md#coco_submit_post) | **POST** /Coco/Submit | Creates a new validation set based on a previously uploaded CoCo set.
*CocoApi* | [**coco_upload_post**](rapidata/api_client/docs/CocoApi.md#coco_upload_post) | **POST** /Coco/Upload | Uploads a CoCo set to the system.
*DatapointApi* | [**datapoint_delete_delete**](rapidata/api_client/docs/DatapointApi.md#datapoint_delete_delete) | **DELETE** /Datapoint/Delete | Delete a datapoint.
*DatapointApi* | [**datapoint_get_all_datapoints_by_dataset_id_get**](rapidata/api_client/docs/DatapointApi.md#datapoint_get_all_datapoints_by_dataset_id_get) | **GET** /Datapoint/GetAllDatapointsByDatasetId | Get all datapoints of a dataset.
*DatapointApi* | [**datapoint_get_by_id_get**](rapidata/api_client/docs/DatapointApi.md#datapoint_get_by_id_get) | **GET** /Datapoint/GetById | Get a datapoint by its id.
*DatasetApi* | [**dataset_create_datapoint_post**](rapidata/api_client/docs/DatasetApi.md#dataset_create_datapoint_post) | **POST** /Dataset/CreateDatapoint | Creates a single datapoint.
*DatasetApi* | [**dataset_get_by_id_get**](rapidata/api_client/docs/DatasetApi.md#dataset_get_by_id_get) | **GET** /Dataset/GetById | Gets a dataset by its id.
*DatasetApi* | [**dataset_import_post**](rapidata/api_client/docs/DatasetApi.md#dataset_import_post) | **POST** /Dataset/Import | Imports datapoints from a csv file.
*DatasetApi* | [**dataset_update_name_post**](rapidata/api_client/docs/DatasetApi.md#dataset_update_name_post) | **POST** /Dataset/UpdateName | Updates the name of a dataset.
*DatasetApi* | [**dataset_upload_datapoint_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_datapoint_post) | **POST** /Dataset/UploadDatapoint | Creates a new multi asset datapoint.
*DatasetApi* | [**dataset_upload_files_from_s3_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_files_from_s3_post) | **POST** /Dataset/UploadFilesFromS3 | Uploads files from an S3 bucket to a dataset.
*DatasetApi* | [**dataset_upload_images_to_dataset_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_images_to_dataset_post) | **POST** /Dataset/UploadImagesToDataset | Uploads images to a dataset.
*DatasetApi* | [**dataset_upload_text_sources_to_dataset_post**](rapidata/api_client/docs/DatasetApi.md#dataset_upload_text_sources_to_dataset_post) | **POST** /Dataset/UploadTextSourcesToDataset | Creates new datapoints from text sources.
*IdentityApi* | [**identity_confirm_get**](rapidata/api_client/docs/IdentityApi.md#identity_confirm_get) | **GET** /Identity/Confirm | Confirms a user&#39;s signup by a token.
*IdentityApi* | [**identity_create_client_post**](rapidata/api_client/docs/IdentityApi.md#identity_create_client_post) | **POST** /Identity/CreateClient | Creates a new client for a customer.
*IdentityApi* | [**identity_external_login_callback_get**](rapidata/api_client/docs/IdentityApi.md#identity_external_login_callback_get) | **GET** /Identity/ExternalLoginCallback | Logs in a user using after receiving a grant from an external provider.
*IdentityApi* | [**identity_external_login_post**](rapidata/api_client/docs/IdentityApi.md#identity_external_login_post) | **POST** /Identity/ExternalLogin | Logs in a user using an external provider.
*IdentityApi* | [**identity_get_auth_token_get**](rapidata/api_client/docs/IdentityApi.md#identity_get_auth_token_get) | **GET** /Identity/GetAuthToken | Issues a new auth token using the refresh token.
*IdentityApi* | [**identity_get_client_auth_token_post**](rapidata/api_client/docs/IdentityApi.md#identity_get_client_auth_token_post) | **POST** /Identity/GetClientAuthToken | Issues a new auth token using the client credentials.
*IdentityApi* | [**identity_index_post**](rapidata/api_client/docs/IdentityApi.md#identity_index_post) | **POST** /Identity/Index | Logs in a user by username or email and password.
*IdentityApi* | [**identity_logout_post**](rapidata/api_client/docs/IdentityApi.md#identity_logout_post) | **POST** /Identity/Logout | Logs out the current user by deleting the refresh token cookie.
*IdentityApi* | [**identity_request_reset_post**](rapidata/api_client/docs/IdentityApi.md#identity_request_reset_post) | **POST** /Identity/RequestReset | Request a password reset for a user.
*IdentityApi* | [**identity_signup_post**](rapidata/api_client/docs/IdentityApi.md#identity_signup_post) | **POST** /Identity/Signup | Signs up a new user.
*IdentityApi* | [**identity_submit_reset_post**](rapidata/api_client/docs/IdentityApi.md#identity_submit_reset_post) | **POST** /Identity/SubmitReset | Updates the password of a user after a password reset request.
*IdentityApi* | [**identity_temporary_post**](rapidata/api_client/docs/IdentityApi.md#identity_temporary_post) | **POST** /Identity/Temporary | Creates a new temporary user.
*NewsletterApi* | [**newsletter_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_post) | **POST** /Newsletter | Signs a user up to the newsletter.
*NewsletterApi* | [**newsletter_unsubscribe_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_unsubscribe_post) | **POST** /Newsletter/Unsubscribe | Unsubscribes a user from the newsletter.
*OrderApi* | [**order_approve_post**](rapidata/api_client/docs/OrderApi.md#order_approve_post) | **POST** /Order/Approve | Approves an order that has been submitted for manual approval.
*OrderApi* | [**order_clone_order_post**](rapidata/api_client/docs/OrderApi.md#order_clone_order_post) | **POST** /Order/CloneOrder | Clones an existing order.
*OrderApi* | [**order_create_complex_order_post**](rapidata/api_client/docs/OrderApi.md#order_create_complex_order_post) | **POST** /Order/CreateComplexOrder | Creates a new order with a custom pipeline.
*OrderApi* | [**order_create_default_order_post**](rapidata/api_client/docs/OrderApi.md#order_create_default_order_post) | **POST** /Order/CreateDefaultOrder | Creates a new order with a default pipeline.
*OrderApi* | [**order_create_post**](rapidata/api_client/docs/OrderApi.md#order_create_post) | **POST** /Order/Create | Used to create a new order.
*OrderApi* | [**order_create_unsupported_order_post**](rapidata/api_client/docs/OrderApi.md#order_create_unsupported_order_post) | **POST** /Order/CreateUnsupportedOrder | Notifies the admins that a user wants to create an order with an unsupported label type or data type.
*OrderApi* | [**order_delete_delete**](rapidata/api_client/docs/OrderApi.md#order_delete_delete) | **DELETE** /Order/Delete | Deletes an order.
*OrderApi* | [**order_feedback_post**](rapidata/api_client/docs/OrderApi.md#order_feedback_post) | **POST** /Order/Feedback | Submits feedback about our services.
*OrderApi* | [**order_get_by_id_get**](rapidata/api_client/docs/OrderApi.md#order_get_by_id_get) | **GET** /Order/GetById | Retrieves an order by its id.
*OrderApi* | [**order_get_order_results_get**](rapidata/api_client/docs/OrderApi.md#order_get_order_results_get) | **GET** /Order/GetOrderResults | Aggregates the results of an order.
*OrderApi* | [**order_get_public_get**](rapidata/api_client/docs/OrderApi.md#order_get_public_get) | **GET** /Order/GetPublic | Retrieves orders that are public and can be cloned by any user.
*OrderApi* | [**order_get_workflow_config_get**](rapidata/api_client/docs/OrderApi.md#order_get_workflow_config_get) | **GET** /Order/GetWorkflowConfig | Retrieves the workflow configuration for an order.
*OrderApi* | [**order_query_get**](rapidata/api_client/docs/OrderApi.md#order_query_get) | **GET** /Order/Query | Queries orders based on a filter, page, and sort criteria.
*OrderApi* | [**order_result_get**](rapidata/api_client/docs/OrderApi.md#order_result_get) | **GET** /Order/Result | Aggregates the results of an order.
*OrderApi* | [**order_retry_failed_post**](rapidata/api_client/docs/OrderApi.md#order_retry_failed_post) | **POST** /Order/RetryFailed | Retries a failed order.
*OrderApi* | [**order_share_put**](rapidata/api_client/docs/OrderApi.md#order_share_put) | **PUT** /Order/Share | Updates whether an order is public or not.
*OrderApi* | [**order_submit_post**](rapidata/api_client/docs/OrderApi.md#order_submit_post) | **POST** /Order/Submit | Submits an order for approval.
*OrderApi* | [**order_unlock_post**](rapidata/api_client/docs/OrderApi.md#order_unlock_post) | **POST** /Order/Unlock | Unlocks a newly cloned order.
*OrderApi* | [**order_update_access_put**](rapidata/api_client/docs/OrderApi.md#order_update_access_put) | **PUT** /Order/UpdateAccess | Updates whether an order is public or not.
*OrderApi* | [**order_update_order_name_put**](rapidata/api_client/docs/OrderApi.md#order_update_order_name_put) | **PUT** /Order/UpdateOrderName | Updates the name of an order.
*OrderApi* | [**order_update_workflow_config_put**](rapidata/api_client/docs/OrderApi.md#order_update_workflow_config_put) | **PUT** /Order/UpdateWorkflowConfig | Updates the workflow configuration of an order.
*RapidApi* | [**rapid_add_user_guess_post**](rapidata/api_client/docs/RapidApi.md#rapid_add_user_guess_post) | **POST** /Rapid/AddUserGuess | Submits a user guess for a Rapid.
*RapidApi* | [**rapid_create_demographic_rapid_post**](rapidata/api_client/docs/RapidApi.md#rapid_create_demographic_rapid_post) | **POST** /Rapid/CreateDemographicRapid | Creates a new Demographic Rapid.
*RapidApi* | [**rapid_query_validation_rapids_get**](rapidata/api_client/docs/RapidApi.md#rapid_query_validation_rapids_get) | **GET** /Rapid/QueryValidationRapids | Queries the validation rapids for a specific validation set.
*RapidApi* | [**rapid_skip_user_guess_post**](rapidata/api_client/docs/RapidApi.md#rapid_skip_user_guess_post) | **POST** /Rapid/SkipUserGuess | Skips a Rapid for the user.
*RapidApi* | [**rapid_validate_current_rapid_bag_get**](rapidata/api_client/docs/RapidApi.md#rapid_validate_current_rapid_bag_get) | **GET** /Rapid/ValidateCurrentRapidBag | Validates that the rapids associated with the current user are active.
*ValidationApi* | [**validation_add_validation_rapid_post**](rapidata/api_client/docs/ValidationApi.md#validation_add_validation_rapid_post) | **POST** /Validation/AddValidationRapid | Adds a new validation rapid to the specified validation set.
*ValidationApi* | [**validation_create_validation_set_post**](rapidata/api_client/docs/ValidationApi.md#validation_create_validation_set_post) | **POST** /Validation/CreateValidationSet | Creates a new empty validation set.
*ValidationApi* | [**validation_get_available_validation_sets_get**](rapidata/api_client/docs/ValidationApi.md#validation_get_available_validation_sets_get) | **GET** /Validation/GetAvailableValidationSets | Gets the available validation sets for the current user.
*ValidationApi* | [**validation_import_compare_post**](rapidata/api_client/docs/ValidationApi.md#validation_import_compare_post) | **POST** /Validation/ImportCompare | Imports a compare validation set from a zip file.
*ValidationApi* | [**validation_import_post**](rapidata/api_client/docs/ValidationApi.md#validation_import_post) | **POST** /Validation/Import | Imports a validation set from a zip file.
*ValidationApi* | [**validation_query_validation_sets_get**](rapidata/api_client/docs/ValidationApi.md#validation_query_validation_sets_get) | **GET** /Validation/QueryValidationSets | Queries validation sets based on the provided filter, paging and sorting criteria.


## Documentation For Models

 - [AddValidationRapidModel](rapidata/api_client/docs/AddValidationRapidModel.md)
 - [AddValidationRapidModelPayload](rapidata/api_client/docs/AddValidationRapidModelPayload.md)
 - [AddValidationRapidModelTruth](rapidata/api_client/docs/AddValidationRapidModelTruth.md)
 - [AddValidationRapidResult](rapidata/api_client/docs/AddValidationRapidResult.md)
 - [AdminOrderModel](rapidata/api_client/docs/AdminOrderModel.md)
 - [AdminOrderModelPagedResult](rapidata/api_client/docs/AdminOrderModelPagedResult.md)
 - [AgeGroup](rapidata/api_client/docs/AgeGroup.md)
 - [AgeUserFilterModel](rapidata/api_client/docs/AgeUserFilterModel.md)
 - [AggregatorType](rapidata/api_client/docs/AggregatorType.md)
 - [AttachCategoryRapidBlueprint](rapidata/api_client/docs/AttachCategoryRapidBlueprint.md)
 - [AttachCategoryResult](rapidata/api_client/docs/AttachCategoryResult.md)
 - [AttachCategoryTruth](rapidata/api_client/docs/AttachCategoryTruth.md)
 - [BaseError](rapidata/api_client/docs/BaseError.md)
 - [BoundingBoxPayload](rapidata/api_client/docs/BoundingBoxPayload.md)
 - [BoundingBoxRapidBlueprint](rapidata/api_client/docs/BoundingBoxRapidBlueprint.md)
 - [BoundingBoxResult](rapidata/api_client/docs/BoundingBoxResult.md)
 - [BoundingBoxTruth](rapidata/api_client/docs/BoundingBoxTruth.md)
 - [BoxShape](rapidata/api_client/docs/BoxShape.md)
 - [CampaignUserFilterModel](rapidata/api_client/docs/CampaignUserFilterModel.md)
 - [ClassificationMetadata](rapidata/api_client/docs/ClassificationMetadata.md)
 - [ClassificationMetadataFilterConfig](rapidata/api_client/docs/ClassificationMetadataFilterConfig.md)
 - [ClassifyPayload](rapidata/api_client/docs/ClassifyPayload.md)
 - [CloneDatasetModel](rapidata/api_client/docs/CloneDatasetModel.md)
 - [CloneOrderModel](rapidata/api_client/docs/CloneOrderModel.md)
 - [CloneOrderResult](rapidata/api_client/docs/CloneOrderResult.md)
 - [ComparePayload](rapidata/api_client/docs/ComparePayload.md)
 - [CompareRapidBlueprint](rapidata/api_client/docs/CompareRapidBlueprint.md)
 - [CompareResult](rapidata/api_client/docs/CompareResult.md)
 - [CompareTruth](rapidata/api_client/docs/CompareTruth.md)
 - [CompareWorkflowConfig](rapidata/api_client/docs/CompareWorkflowConfig.md)
 - [CompareWorkflowConfigRapidSelectionConfigsInner](rapidata/api_client/docs/CompareWorkflowConfigRapidSelectionConfigsInner.md)
 - [CompareWorkflowConfigReferee](rapidata/api_client/docs/CompareWorkflowConfigReferee.md)
 - [CompareWorkflowModel](rapidata/api_client/docs/CompareWorkflowModel.md)
 - [ConditionalValidationRapidSelectionConfig](rapidata/api_client/docs/ConditionalValidationRapidSelectionConfig.md)
 - [Coordinate](rapidata/api_client/docs/Coordinate.md)
 - [CorrelatedRapidSelectionConfig](rapidata/api_client/docs/CorrelatedRapidSelectionConfig.md)
 - [CountClassificationMetadataFilterConfig](rapidata/api_client/docs/CountClassificationMetadataFilterConfig.md)
 - [CountMetadata](rapidata/api_client/docs/CountMetadata.md)
 - [CountryUserFilterModel](rapidata/api_client/docs/CountryUserFilterModel.md)
 - [CreateClientModel](rapidata/api_client/docs/CreateClientModel.md)
 - [CreateComplexOrderModel](rapidata/api_client/docs/CreateComplexOrderModel.md)
 - [CreateComplexOrderModelPipeline](rapidata/api_client/docs/CreateComplexOrderModelPipeline.md)
 - [CreateComplexOrderResult](rapidata/api_client/docs/CreateComplexOrderResult.md)
 - [CreateDatasetArtifactModel](rapidata/api_client/docs/CreateDatasetArtifactModel.md)
 - [CreateDatasetArtifactModelDataset](rapidata/api_client/docs/CreateDatasetArtifactModelDataset.md)
 - [CreateDefaultOrderModel](rapidata/api_client/docs/CreateDefaultOrderModel.md)
 - [CreateDefaultOrderModelWorkflowConfig](rapidata/api_client/docs/CreateDefaultOrderModelWorkflowConfig.md)
 - [CreateDemographicRapidModel](rapidata/api_client/docs/CreateDemographicRapidModel.md)
 - [CreateEmptyValidationSetResult](rapidata/api_client/docs/CreateEmptyValidationSetResult.md)
 - [CreateLegacyOrderResult](rapidata/api_client/docs/CreateLegacyOrderResult.md)
 - [CreateOrderModel](rapidata/api_client/docs/CreateOrderModel.md)
 - [CreateOrderModelReferee](rapidata/api_client/docs/CreateOrderModelReferee.md)
 - [CreateOrderModelSelectionsInner](rapidata/api_client/docs/CreateOrderModelSelectionsInner.md)
 - [CreateOrderModelUserFiltersInner](rapidata/api_client/docs/CreateOrderModelUserFiltersInner.md)
 - [CreateOrderModelWorkflow](rapidata/api_client/docs/CreateOrderModelWorkflow.md)
 - [CreateOrderResult](rapidata/api_client/docs/CreateOrderResult.md)
 - [CreateSimplePipelineModel](rapidata/api_client/docs/CreateSimplePipelineModel.md)
 - [CreateSimplePipelineModelArtifactsInner](rapidata/api_client/docs/CreateSimplePipelineModelArtifactsInner.md)
 - [CreateSimplePipelineModelPipelineStepsInner](rapidata/api_client/docs/CreateSimplePipelineModelPipelineStepsInner.md)
 - [CreateUnsupportedOrderModel](rapidata/api_client/docs/CreateUnsupportedOrderModel.md)
 - [CustomerOrderModel](rapidata/api_client/docs/CustomerOrderModel.md)
 - [CustomerOrderModelPagedResult](rapidata/api_client/docs/CustomerOrderModelPagedResult.md)
 - [Datapoint](rapidata/api_client/docs/Datapoint.md)
 - [DatapointAsset](rapidata/api_client/docs/DatapointAsset.md)
 - [DatapointGetByIdGet200Response](rapidata/api_client/docs/DatapointGetByIdGet200Response.md)
 - [DatapointMetadataModel](rapidata/api_client/docs/DatapointMetadataModel.md)
 - [DatapointMetadataModelMetadataInner](rapidata/api_client/docs/DatapointMetadataModelMetadataInner.md)
 - [DatapointModel](rapidata/api_client/docs/DatapointModel.md)
 - [DatapointModelAsset](rapidata/api_client/docs/DatapointModelAsset.md)
 - [DatasetEvaluationStepModel](rapidata/api_client/docs/DatasetEvaluationStepModel.md)
 - [DemographicRapidSelectionConfig](rapidata/api_client/docs/DemographicRapidSelectionConfig.md)
 - [DemographicSelection](rapidata/api_client/docs/DemographicSelection.md)
 - [EarlyStoppingRefereeModel](rapidata/api_client/docs/EarlyStoppingRefereeModel.md)
 - [EmptyValidationTruth](rapidata/api_client/docs/EmptyValidationTruth.md)
 - [ErrorType](rapidata/api_client/docs/ErrorType.md)
 - [FeatureFlag](rapidata/api_client/docs/FeatureFlag.md)
 - [FeatureFlagModel](rapidata/api_client/docs/FeatureFlagModel.md)
 - [FeedbackModel](rapidata/api_client/docs/FeedbackModel.md)
 - [FileAsset](rapidata/api_client/docs/FileAsset.md)
 - [FileAssetMetadataInner](rapidata/api_client/docs/FileAssetMetadataInner.md)
 - [FileAssetModel](rapidata/api_client/docs/FileAssetModel.md)
 - [Filter](rapidata/api_client/docs/Filter.md)
 - [FilterOperator](rapidata/api_client/docs/FilterOperator.md)
 - [FreeTextPayload](rapidata/api_client/docs/FreeTextPayload.md)
 - [FreeTextRapidBlueprint](rapidata/api_client/docs/FreeTextRapidBlueprint.md)
 - [FreeTextResult](rapidata/api_client/docs/FreeTextResult.md)
 - [Gender](rapidata/api_client/docs/Gender.md)
 - [GenderUserFilterModel](rapidata/api_client/docs/GenderUserFilterModel.md)
 - [GetAvailableValidationSetsResult](rapidata/api_client/docs/GetAvailableValidationSetsResult.md)
 - [GetDatapointsByDatasetIdResult](rapidata/api_client/docs/GetDatapointsByDatasetIdResult.md)
 - [GetDatasetByIdResult](rapidata/api_client/docs/GetDatasetByIdResult.md)
 - [GetOrderByIdResult](rapidata/api_client/docs/GetOrderByIdResult.md)
 - [GetOrderResultsResult](rapidata/api_client/docs/GetOrderResultsResult.md)
 - [GetPublicOrdersResult](rapidata/api_client/docs/GetPublicOrdersResult.md)
 - [GetWorkflowConfigResult](rapidata/api_client/docs/GetWorkflowConfigResult.md)
 - [GetWorkflowConfigResultWorkflowConfig](rapidata/api_client/docs/GetWorkflowConfigResultWorkflowConfig.md)
 - [ImageDimensionMetadata](rapidata/api_client/docs/ImageDimensionMetadata.md)
 - [ImportFromFileResult](rapidata/api_client/docs/ImportFromFileResult.md)
 - [ImportValidationSetFromFileResult](rapidata/api_client/docs/ImportValidationSetFromFileResult.md)
 - [IssueAuthTokenResult](rapidata/api_client/docs/IssueAuthTokenResult.md)
 - [IssueClientAuthTokenResult](rapidata/api_client/docs/IssueClientAuthTokenResult.md)
 - [LabelingSelection](rapidata/api_client/docs/LabelingSelection.md)
 - [LanguageUserFilterModel](rapidata/api_client/docs/LanguageUserFilterModel.md)
 - [Line](rapidata/api_client/docs/Line.md)
 - [LinePayload](rapidata/api_client/docs/LinePayload.md)
 - [LinePoint](rapidata/api_client/docs/LinePoint.md)
 - [LineRapidBlueprint](rapidata/api_client/docs/LineRapidBlueprint.md)
 - [LineResult](rapidata/api_client/docs/LineResult.md)
 - [LineTruth](rapidata/api_client/docs/LineTruth.md)
 - [LocateBoxTruth](rapidata/api_client/docs/LocateBoxTruth.md)
 - [LocateCoordinate](rapidata/api_client/docs/LocateCoordinate.md)
 - [LocatePayload](rapidata/api_client/docs/LocatePayload.md)
 - [LocateRapidBlueprint](rapidata/api_client/docs/LocateRapidBlueprint.md)
 - [LocateResult](rapidata/api_client/docs/LocateResult.md)
 - [LocationMetadata](rapidata/api_client/docs/LocationMetadata.md)
 - [LocationMetadataExistsFilterConfig](rapidata/api_client/docs/LocationMetadataExistsFilterConfig.md)
 - [LogicOperator](rapidata/api_client/docs/LogicOperator.md)
 - [LoginModel](rapidata/api_client/docs/LoginModel.md)
 - [MetadataVisibilities](rapidata/api_client/docs/MetadataVisibilities.md)
 - [MultiAsset](rapidata/api_client/docs/MultiAsset.md)
 - [MultiAssetModel](rapidata/api_client/docs/MultiAssetModel.md)
 - [NaiveRefereeConfig](rapidata/api_client/docs/NaiveRefereeConfig.md)
 - [NaiveRefereeModel](rapidata/api_client/docs/NaiveRefereeModel.md)
 - [NamedClassification](rapidata/api_client/docs/NamedClassification.md)
 - [NamedEntityPayload](rapidata/api_client/docs/NamedEntityPayload.md)
 - [NamedEntityRapidBlueprint](rapidata/api_client/docs/NamedEntityRapidBlueprint.md)
 - [NamedEntityResult](rapidata/api_client/docs/NamedEntityResult.md)
 - [NamedEntityTruth](rapidata/api_client/docs/NamedEntityTruth.md)
 - [NeverEndingRefereeConfig](rapidata/api_client/docs/NeverEndingRefereeConfig.md)
 - [NewsletterModel](rapidata/api_client/docs/NewsletterModel.md)
 - [NoValidationWorkflowRapidSelectionConfig](rapidata/api_client/docs/NoValidationWorkflowRapidSelectionConfig.md)
 - [NullAsset](rapidata/api_client/docs/NullAsset.md)
 - [NullAssetModel](rapidata/api_client/docs/NullAssetModel.md)
 - [OnlyValidationWorkflowRapidSelectionConfig](rapidata/api_client/docs/OnlyValidationWorkflowRapidSelectionConfig.md)
 - [OrderModel](rapidata/api_client/docs/OrderModel.md)
 - [OrderQueryGet200Response](rapidata/api_client/docs/OrderQueryGet200Response.md)
 - [OriginalFilenameMetadata](rapidata/api_client/docs/OriginalFilenameMetadata.md)
 - [PageInfo](rapidata/api_client/docs/PageInfo.md)
 - [PolygonPayload](rapidata/api_client/docs/PolygonPayload.md)
 - [PolygonRapidBlueprint](rapidata/api_client/docs/PolygonRapidBlueprint.md)
 - [PolygonResult](rapidata/api_client/docs/PolygonResult.md)
 - [PolygonTruth](rapidata/api_client/docs/PolygonTruth.md)
 - [PrivateTextMetadataInput](rapidata/api_client/docs/PrivateTextMetadataInput.md)
 - [ProbabilisticAttachCategoryRefereeConfig](rapidata/api_client/docs/ProbabilisticAttachCategoryRefereeConfig.md)
 - [PromptMetadata](rapidata/api_client/docs/PromptMetadata.md)
 - [PromptMetadataInput](rapidata/api_client/docs/PromptMetadataInput.md)
 - [PublicTextMetadataInput](rapidata/api_client/docs/PublicTextMetadataInput.md)
 - [QueryModel](rapidata/api_client/docs/QueryModel.md)
 - [QueryOrdersModel](rapidata/api_client/docs/QueryOrdersModel.md)
 - [QueryValidationRapidsResult](rapidata/api_client/docs/QueryValidationRapidsResult.md)
 - [QueryValidationRapidsResultAsset](rapidata/api_client/docs/QueryValidationRapidsResultAsset.md)
 - [QueryValidationRapidsResultPagedResult](rapidata/api_client/docs/QueryValidationRapidsResultPagedResult.md)
 - [QueryValidationSetModel](rapidata/api_client/docs/QueryValidationSetModel.md)
 - [RapidResultModel](rapidata/api_client/docs/RapidResultModel.md)
 - [RapidResultModelResult](rapidata/api_client/docs/RapidResultModelResult.md)
 - [RapidSkippedModel](rapidata/api_client/docs/RapidSkippedModel.md)
 - [RequestPasswordResetCommand](rapidata/api_client/docs/RequestPasswordResetCommand.md)
 - [RootFilter](rapidata/api_client/docs/RootFilter.md)
 - [SendCompletionMailStepModel](rapidata/api_client/docs/SendCompletionMailStepModel.md)
 - [Shape](rapidata/api_client/docs/Shape.md)
 - [SignupCustomerModel](rapidata/api_client/docs/SignupCustomerModel.md)
 - [SignupShadowCustomerModel](rapidata/api_client/docs/SignupShadowCustomerModel.md)
 - [SimpleWorkflowConfig](rapidata/api_client/docs/SimpleWorkflowConfig.md)
 - [SimpleWorkflowConfigBlueprint](rapidata/api_client/docs/SimpleWorkflowConfigBlueprint.md)
 - [SimpleWorkflowModel](rapidata/api_client/docs/SimpleWorkflowModel.md)
 - [SimpleWorkflowModelBlueprint](rapidata/api_client/docs/SimpleWorkflowModelBlueprint.md)
 - [SkipResult](rapidata/api_client/docs/SkipResult.md)
 - [SortCriterion](rapidata/api_client/docs/SortCriterion.md)
 - [SortDirection](rapidata/api_client/docs/SortDirection.md)
 - [StaticRapidSelectionConfig](rapidata/api_client/docs/StaticRapidSelectionConfig.md)
 - [SubmitCocoModel](rapidata/api_client/docs/SubmitCocoModel.md)
 - [SubmitCocoResult](rapidata/api_client/docs/SubmitCocoResult.md)
 - [SubmitPasswordResetCommand](rapidata/api_client/docs/SubmitPasswordResetCommand.md)
 - [TextAsset](rapidata/api_client/docs/TextAsset.md)
 - [TextAssetModel](rapidata/api_client/docs/TextAssetModel.md)
 - [TextMetadata](rapidata/api_client/docs/TextMetadata.md)
 - [TranscriptionMetadata](rapidata/api_client/docs/TranscriptionMetadata.md)
 - [TranscriptionMetadataInput](rapidata/api_client/docs/TranscriptionMetadataInput.md)
 - [TranscriptionPayload](rapidata/api_client/docs/TranscriptionPayload.md)
 - [TranscriptionRapidBlueprint](rapidata/api_client/docs/TranscriptionRapidBlueprint.md)
 - [TranscriptionResult](rapidata/api_client/docs/TranscriptionResult.md)
 - [TranscriptionTruth](rapidata/api_client/docs/TranscriptionTruth.md)
 - [TranscriptionWord](rapidata/api_client/docs/TranscriptionWord.md)
 - [UnlockOrderResult](rapidata/api_client/docs/UnlockOrderResult.md)
 - [UpdateAccessModel](rapidata/api_client/docs/UpdateAccessModel.md)
 - [UpdateOrderModel](rapidata/api_client/docs/UpdateOrderModel.md)
 - [UpdateWorkflowConfigModel](rapidata/api_client/docs/UpdateWorkflowConfigModel.md)
 - [UpdateWorkflowConfigModelWorkflowConfig](rapidata/api_client/docs/UpdateWorkflowConfigModelWorkflowConfig.md)
 - [UploadCocoResult](rapidata/api_client/docs/UploadCocoResult.md)
 - [UploadDatapointsResult](rapidata/api_client/docs/UploadDatapointsResult.md)
 - [UploadFilesFromS3BucketModel](rapidata/api_client/docs/UploadFilesFromS3BucketModel.md)
 - [UploadTextSourcesToDatasetModel](rapidata/api_client/docs/UploadTextSourcesToDatasetModel.md)
 - [UserScoreUserFilterModel](rapidata/api_client/docs/UserScoreUserFilterModel.md)
 - [ValidationChance](rapidata/api_client/docs/ValidationChance.md)
 - [ValidationImportPostRequestBlueprint](rapidata/api_client/docs/ValidationImportPostRequestBlueprint.md)
 - [ValidationRapidSelectionConfig](rapidata/api_client/docs/ValidationRapidSelectionConfig.md)
 - [ValidationSelection](rapidata/api_client/docs/ValidationSelection.md)
 - [ValidationSet](rapidata/api_client/docs/ValidationSet.md)
 - [ValidationSetOverviewModel](rapidata/api_client/docs/ValidationSetOverviewModel.md)
 - [ValidationSetPagedResult](rapidata/api_client/docs/ValidationSetPagedResult.md)
 - [WorkflowAggregationStepModel](rapidata/api_client/docs/WorkflowAggregationStepModel.md)
 - [WorkflowLabelingStepModel](rapidata/api_client/docs/WorkflowLabelingStepModel.md)
 - [WorkflowSplitModel](rapidata/api_client/docs/WorkflowSplitModel.md)
 - [WorkflowSplitModelFilterConfigsInner](rapidata/api_client/docs/WorkflowSplitModelFilterConfigsInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearer"></a>
### bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




